# MieLib

Library which contains many Mie-ralated functions in optics and acoustics. In particular:
- Scattering Mie coefficients for isotropic spheres:
    -  Acoustic Mie coefficients based on Phys. Rev. Lett. 123, 183901 (2019) (see SM)
    - Optics Mie coefficients based on Bohren Huffmann book.
- Scalar spherical harmonics
- Vector spherical harmonics (complex and real)


## Credits
Ivan Toftul 

`toftul.ivan@gmail.com`
